#include "TNOSQL.CH"

/*
Ŀ
 Programa:     tno03.prg                                                 
 Parmetros:   Ninguno                                                   
 Utilidad:     Crea una tabla y almacena comandos para manejarla         
Ĵ
 Compilacin y enlace:                                                   
 clipper tno03 /w /n                                                     
 blinker fi tno03 li tnosql1                                             

 
*/

FUNC tno03()

   LOCAL hCursor, nError

   Presenta()

   /// Conexin a la base DEMO
   QOut( "Conectandose a la base ..." )

   IF ( nError := sqlCntCursor( @hCursor, "DEMO" ) ) == 0
      sql_Success( "Conexin satisfactoria ..." )

      /// Creacin de la tabla TNODemo
      IF sqlComExe( hCursor, ;
         "CREATE TABLE TNODEMO (CODIGO NUMBER NOT NULL, NOMBRE CHAR(30), " + ;
         "NACIMIENTO DATE, PRIMARY KEY (CODIGO))" )
         sql_Success( "Tabla creada satisfactoriamente ..." )

         /// Creacin del ndice de la clave primaria
         IF sqlComExe( hCursor, "CREATE UNIQUE INDEX TNOINDEX ON TNODEMO (CODIGO)" )
            sql_Success( "Indice creado para tabla TNODemo ..." )
         ELSE
            sql_Error( sqlLastCode( hCursor ) )
         ENDIF

         /// Almacenamiento de comandos
         IF sqlStoreCmd( hCursor, "TNOINSERT", ;
            "INSERT INTO TNODEMO VALUES ( :1, :2, :3 )" )
            sql_Success( "Comando INSERT almacenado ..." )
         ELSE
            sql_Error( sqlLastCode( hCursor ) )
         ENDIF

         IF sqlStoreCmd( hCursor, "TNODELETE", ;
            "DELETE FROM TNODEMO WHERE codigo = :1" )
            sql_Success( "Comando DELETE almacenado ..." )
         ELSE
            sql_Error( sqlLastCode( hCursor ) )
         ENDIF

         IF sqlStoreCmd( hCursor, "TNOSELECT", ;
            "SELECT NOMBRE, NACIMIENTO FROM TNODEMO WHERE codigo = :1" )
            sql_Success( "Comando SELECT almacenado ..." )
         ELSE
            sql_Error( sqlLastCode( hCursor ) )
         ENDIF

         IF sqlStoreCmd( hCursor, "TNOUPDATE", ;
            "UPDATE TNODEMO SET nombre = :1, nacimiento = :2 WHERE codigo = :3" )
            sql_Success( "Comando UPDATE almacenado ..." )
         ELSE
            sql_Error( sqlLastCode( hCursor ) )
         ENDIF

         sql_Success( "Comandos compilados y almacenados en la base ..." )

      ELSE
         sql_Error( sqlLastCode( hCursor ) )
         InKey( 5 )
      ENDIF

      /// Desconexin de la base 
      sqlDisCursor( hCursor )
   ELSE
      sql_Error( nError )
      InKey( 5 )
   ENDIF

   Bye()

RETURN ( Nil )



/*
Ŀ
 Funcin:      sql_Error()                                               
 Parmetros:   Cdigo de error                                           
 Utilidad:     Displaya el mensaje del error en rojo                     

 
*/

STAT FUNC sql_Error( nError )
   LOCAL cColor := SetColor( "r/n" )

   QOut( sqlErrorMsg( nError ) )
   SetColor( cColor )

RETURN ( Nil )



/*
Ŀ
 Funcin:      sql_Success()                                             
 Parmetros:   Mensaje a displayar                                       
 Utilidad:     Displaya el mensaje en color verde                        

 
*/

STAT FUNC sql_Success( cMsg )
   LOCAL cColor := SetColor( "g/n" )

   QOut( cMsg )
   SetColor( cColor )

RETURN ( Nil )



/*
Ŀ
 Funcin:      Presenta()                                                
 Parmetros:   Pantalla de TNO-SQL 1.0                                   
 Utilidad:     Displaya la pantalla del producto                         

 
*/

STAT FUNC Presenta()
   LOCAL nCursor := SetCursor( 0 )

   IF File( "TNOSQL.SCR" )
      RestScreen( 0, 0, 24, 79, MemoRead( "TNOSQL.SCR" ) )
      InKey( 10 )
   ENDIF                          

   Scroll()
   SetCursor( nCursor )
RETURN ( Nil )



/*
Ŀ
 Funcin:      Bye()                                                     
 Parmetros:   Ninguno                                                   
 Utilidad:     Displaya la pantalla del final                            

 
*/

STAT FUNC Bye()
   Scroll()   
   @ 0, 0 SAY Replicate( '', 80 ) COLOR "+b/n"
   @ 1, 0 SAY PadC( "TNO-SQL 1.0 para Gupta SQLBase 5.0", 80 ) COLOR "w/n"
   @ 2, 0 SAY PadC( "por Guillermo Gisinger", 80 ) COLOR "w/n"
   @ 4, 0 SAY PadC( "Copyright (c) The New Order Corporation  1994", 80 ) ;
   COLOR "w/n"
   @ 5, 0 SAY PadC( "All Rights Reserved", 80 ) COLOR "w/n"
   @ 6, 0 SAY Replicate( '', 80 ) COLOR "+b/n"
   SetPos( 8, 0 )
RETURN ( Nil )



/// by LMN   |-)

