#include "TNOSQL.CH"
#include "INKEY.CH"
#include "SET.CH"

/*
Ŀ
 Programa:     tno06.prg                                                 
 Parmetros:   Ninguno                                                   
 Utilidad:     Browse's de cualquier tabla de la base de datos           
Ĵ
 Compilacin y enlace:                                                   
 clipper tno06 /w /n                                                     
 blinker fi tno06 li tnosql1                                             

 
*/

FUNC tno06()

   LOCAL hCursor1, hCursor2, nError    
   LOCAL GetList := {}
   LOCAL cBase, cUser, cPswd

   Set( _SET_CONFIRM, "ON" )
   Set( _SET_DATEFORMAT, "dd/mm/yyyy" )
   Set( _SET_SCOREBOARD, "OFF" )
   SetColor( "w/n,+w/g,,,+w/g" )
   SetCursor( 3 )

   /// Pantalla de presentacin
   Presenta()

   /// Verifico que este instalado el router o la base local
   IF sqlRouter()

      /// Obtengo valores de conexin por defecto
      cBase := PadR( sqlGetPar( 0, SQLPDDB ), 12 )
      cUser := PadR( sqlGetPar( 0, SQLPDUS ), 8 )
      cPswd := PadR( sqlGetPar( 0, SQLPDPW ), 8 )

      /// Pantalla de conexin
      RestScreen( 0, 0, 24, 79, MemoRead( "CONNECT.SCR" ) )
              
      @ 2, 67 GET cBase PICTURE "@!"
      @ 3, 67 GET cUser PICTURE "@!"
      @ 4, 67 GET cPswd PICTURE "@!"
      READ

      SetPos( 11, 0 )

      IF ( LastKey() != K_ESC )

         /// Formo la cadena de conexin
         cBase := RTrim( cBase ) + '/' + RTrim( cUser ) + '/' + ;
         RTrim( cPswd )

         /// Conexin del primer cursor
         IF ( nError := sqlCntCursor( @hCursor1, cBase ) ) == 0
            sql_Success( "Conexin primer cursor realizada ..." )

            /// Conexin del segundo cursor
            IF ( nError := sqlCntCursor( @hCursor2, cBase ) ) == 0
               sql_Success( "Conexin segundo cursor realizada ..." )

               /// Displayo pantalla para los browse's
               RestScreen( 0, 0, 24, 79, MemoRead( "TNO06.SCR" ) )

               /// Fijacin de set de resultados en los cursores y
               /// nivel de aislamiento
               sqlStartRR( hCursor1 )  /// Primer cursor
               sqlStopRtn( hCursor1 )  
               sqlIsoLevel( hCursor1, SQLILRL )

               sqlStartRR( hCursor2 )  /// Segundo cursor
               sqlStopRtn( hCursor2 )                   
               sqlIsoLevel( hCursor2, SQLILRL )

               /// Compilacin del comando para conocer las tablas que
               /// se encuentran en la base
               IF sqlComCmd( hCursor1, "SELECT * FROM SYSTABLES" )

                  /// Inicializacin de buffers de enlace
                  IF ( nError := sqlQryInit( hCursor1 ) ) == 0

                     /// Funcin que se encargar de todo de aqu en mas
                     ShowTables( hCursor1, hCursor2 )

                     /// Liberacin de buffers
                     sqlQryClr( hCursor1 )
                  ELSE
                     sql_Error( nError )
                     InKey( 5 )
                  ENDIF

               ELSE
                  sql_Error( sqlLastCode( hCursor1 ) )
                  InKey( 5 )
               ENDIF

               /// Desconecto los cursores
               sqlDisCursor( hCursor1 )
               sqlDisCursor( hCursor2 )

            ELSE
               /// Desconecto el primer cursor
               sqlDisCursor( hCursor1 )       

               sql_Error( nError )
               InKey( 5 )
            ENDIF
         ELSE
            sql_Error( nError )
            InKey( 5 )
         ENDIF

      ENDIF
   ELSE
      sql_Error( 140 )
      InKey( 5 )
   ENDIF

   Bye()

RETURN ( Nil )



/*
Ŀ
 Funcin:      sql_Error()                                               
 Parmetros:   Cdigo de error                                           
 Utilidad:     Displaya el mensaje del error en rojo                     

 
*/

STAT FUNC sql_Error( nError )
   LOCAL cColor := SetColor( "r/n" )

   QOut( sqlErrorMsg( nError ) )
   SetColor( cColor )

RETURN ( Nil )



/*
Ŀ
 Funcin:      sql_Success()                                             
 Parmetros:   Mensaje a displayar                                       
 Utilidad:     Displaya el mensaje en color verde                        

 
*/

STAT FUNC sql_Success( cMsg )
   LOCAL cColor := SetColor( "g/n" )

   QOut( cMsg )
   SetColor( cColor )

RETURN ( Nil )



/*
Ŀ
 Funcin:      Presenta()                                                
 Parmetros:   Pantalla de TNO-SQL 1.0                                   
 Utilidad:     Displaya la pantalla del producto                         

 
*/

STAT FUNC Presenta()
   LOCAL nCursor := SetCursor( 0 )

   IF File( "TNOSQL.SCR" )
      RestScreen( 0, 0, 24, 79, MemoRead( "TNOSQL.SCR" ) )
      InKey( 10 )
   ENDIF                          

   Scroll()
   SetCursor( nCursor )
RETURN ( Nil )



/*
Ŀ
 Funcin:      Bye()                                                     
 Parmetros:   Ninguno                                                   
 Utilidad:     Displaya la pantalla del final                            

 
*/

STAT FUNC Bye()
   Scroll()   
   @ 0, 0 SAY Replicate( '', 80 ) COLOR "+b/n"
   @ 1, 0 SAY PadC( "TNO-SQL 1.0 para Gupta SQLBase 5.0", 80 ) COLOR "w/n"
   @ 2, 0 SAY PadC( "por Guillermo Gisinger", 80 ) COLOR "w/n"
   @ 4, 0 SAY PadC( "Copyright (c) The New Order Corporation  1994", 80 ) ;
   COLOR "w/n"
   @ 5, 0 SAY PadC( "All Rights Reserved", 80 ) COLOR "w/n"
   @ 6, 0 SAY Replicate( '', 80 ) COLOR "+b/n"
   SetPos( 8, 0 )
RETURN ( Nil )      



/*
Ŀ
 Funcin:      ShowTables()                                              
 Parmetros:   Valores de las conexiones realizadas por la funcin TNO06 
 Utilidad:     Permite elegir tablas de la base de datos y mostrarlas    
               por medio de un browse                                    

 
*/

STAT FUNC ShowTables( hCursor1, hCursor2 )
   LOCAL oSQL, nRow := 1, nRows := sqlSELRows( hCursor1 )
   LOCAL nKey := 0, nCursor := SetCursor( 0 )

   RestScreen( 24, 0, 24, 48, MemoRead( "STAT1.SCR" ) )

   /// Creacin del TBrowse
   oSQL := TBrowseNew( 2, 4, 5, 74 )
   oSQL:ColorSpec := "w/n,+w/rb"
   oSQL:HeadSep   := ""
   oSQL:ColSep    := "  "

   /// Asignacin de codeblock's de reposicionamiento
   oSQL:GoTopBlock    := {|| nRow := 1, sqlSetRow( hCursor1, 1 ) }
   oSQL:GoBottomBlock := {|| nRow := nRows, sqlSetRow( hCursor1, nRows ) }
   oSQL:SkipBlock     := { |n| sqlSkip( n, @nRow, nRows, hCursor1 ) }

   /// Asignacin de columnas
   oSQL:AddColumn( TBColumnNew( "Creador", ;
   { || sqlQryCol( hCursor1, 1 ) } ) )
   oSQL:AddColumn( TBColumnNew( "Tabla", ;
   { || sqlQryCol( hCursor1, 2 ) } ) )
   oSQL:AddColumn( TBColumnNew( "Columnas", ;
   { || Str( sqlQryCol( hCursor1, 3 ), 2 ) } ) )

   WHILE ( nKey != K_ESC )

      WHILE !oSQL:Stabilize()
      ENDDO

      IF oSQL:HitTop .OR. oSQL:HitBottom
         Tone( 300, 1 )
         oSQL:HitTop := oSQL:HitBottom := .F.
      ENDIF

      oSQL:ColorRect( { oSQL:RowPos, 1, oSQL:RowPos, 3 }, { 2, 2 } )
      nKey := InKey( 0 )
      oSQL:ColorRect( { oSQL:RowPos, 1, oSQL:RowPos, 3 }, { 1, 1 } )

      DO CASE
         CASE nKey == K_UP
            oSQL:Up()
         CASE nKey == K_DOWN
            oSQL:Down()
         CASE nKey == K_PGUP
            oSQL:PageUp()
         CASE nKey == K_PGDN
            oSQL:PageDown()
         CASE nKey == K_HOME
            oSQL:GoTop()
         CASE nKey == K_END
            oSQL:GoBottom()
         CASE nKey == K_ENTER
            LookInside( hCursor2, sqlQryCol( hCursor1, 1 ), ;
            sqlQryCol( hCursor1, 2 ) )
      ENDCASE

   ENDDO

   SetCursor( nCursor )

RETURN ( Nil )



/*
Ŀ
 Funcin:      LookInside()                                              
 Parmetros:   Valor del cursor de la segunda conexin y datos de la ta- 
               bla que ser mostrada                                     
 Utilidad:     Permite mirar los registros de las tablas                 

 
*/          

STAT FUNC LookInside( hCursor2, cCreator, cTable )
   LOCAL cSelect := "SELECT * FROM ", nError
   LOCAL cScreen := SaveScreen( 9, 0, 24, 79 )        
   LOCAL oTab, nRow := 1, nRows, nKey := 0, nCols, nCol
   LOCAL acHNames := {}

   @ 9, 5 SAY ' ' + RTrim( cTable ) + ' ' COLOR "+w/g"
   RestScreen( 24, 0, 24, 48, MemoRead( "STAT2.SCR" ) )

   /// Comando SELECT que se ejecutar
   cSelect += RTrim( cCreator ) + '.' + RTrim( cTable )

   /// Compilacin del comando
   IF sqlComCmd( hCursor2, cSelect )

      /// Cantidad de columnas y obtencin de los nombres
      nCols := sqlCCount( hCursor2 )
      FOR nCol := 1 TO nCols
         AAdd( acHNames, sqlGetHeader( hCursor2, nCol ) )
      NEXT

      /// Inicializacin de buffers de intercambio
      IF ( nError := sqlQryInit( hCursor2 ) ) == 0                         

         /// Cantidad de filas 
         nRows := sqlSELRows( hCursor2 ) 

         oTab := TBrowseNew( 10, 4, 19, 74 )
         oTab:ColorSpec := "w/n,+w/b"
         oTab:HeadSep   := ""
         oTab:ColSep    := "  "
         
         oTab:GoTopBlock    := { || nRow := 1, sqlSetRow( hCursor2, 1 ) }
         oTab:GoBottomBlock := { || nRow := nRows, ;
         sqlSetRow( hCursor2, nRows ) }
         oTab:SkipBlock     := { |n| sqlSkip( n, @nRow, nRows, hCursor2 ) }

         /// Asignacin de columnas
         FOR nCol := 1 TO nCols    
            oTab:AddColumn( TBColumnNew( acHNames[ nCol ], ;
            ColBlock( hCursor2, nCol ) ) )
         NEXT

         IF ( nRows > 0 )

            WHILE ( nKey != K_ESC )

               WHILE !oTab:Stabilize()
               ENDDO

               IF oTab:HitTop .OR. oTab:HitBottom
                  Tone( 300, 1 )
                  oTab:HitTop := oTab:HitBottom := .F.
               ENDIF

               nKey := InKey( 0 )

               DO CASE
                  CASE nKey == K_UP
                     oTab:Up()
                  CASE nKey == K_DOWN
                     oTab:Down()
                  CASE nKey == K_PGUP
                     oTab:PageUp()
                  CASE nKey == K_PGDN
                     oTab:PageDown()
                  CASE nKey == K_HOME
                     oTab:GoTop()
                  CASE nKey == K_END
                     oTab:GoBottom()
                  CASE nKey == K_LEFT
                     oTab:Left()
                  CASE nKey == K_RIGHT
                     oTab:Right()
               ENDCASE

            ENDDO

         ELSE
            Alert( "La tabla se encuentra vaca ...", { "  OK  " } )
         ENDIF

         /// Limpieza de buffers de intercambio
         sqlQryClr( hCursor2 )
      ELSE
         Alert( sqlErrorMsg( nError ), { " Volver " } )
      ENDIF
   ELSE
      Alert( sqlErrorMsg( sqlLastCode( hCursor2 ) ) )
   ENDIF                              

   RestScreen( 9, 0, 24, 79, cScreen )

RETURN ( Nil )



/*
Ŀ
 Funcin:      ColBlock()                                                
 Parmetros:   Valor del cursor de la segunda conexin y nmero de co-   
               lumna que usar para crear el codeblock                   
 Utilidad:     Crear los codeblock's para el TBrowse                     

 
*/          

STAT FUNC ColBlock( hCursor, nCol )
RETURN ( { || sqlQryCol( hCursor, nCol ) } )



/// by LMN   |-)
