/*

      \ \  \   \        \    \   \       
         \    \ \  \  \      \       \  \  \       
         \    \\\ \  \ 1.0  \  \  \ \       
         \    \ \  \  \           \  \\\  \       
         \    \  \   \       \    \\  \  

   Archivo cabecera de la librera
   Copyright (c) 1994 by Guillermo Gisinger
   All rights reserved

   Guillermo Gisinger - The New Order Corporation

*/


/* EoF for SQL Fetch */
#define SQLEOF    1




/* SET and GET PARAMETER TYPES */

/*	Global parameters                                                   */
#define   SQLPDDB   1			/* default database name	    */
#define   SQLPDUS   2			/* default user name		    */
#define   SQLPDPW   3			/* default password		    */
#define   SQLPGBC   10004		/* global cursor value		    */
#define   SQLPLRD   5			/* local result set directory	    */
#define   SQLPDBM   6			/* db mode - see below		    */
#define   SQLPDBD   7			/* dbdir			    */
#define   SQLPCPG   8			/* code page information	    */
#define   SQLPNIE   10009		/* null indicator error 	    */

/*	Server specific parameters                                          */
#define   SQLPHEP   11001		/* HEAP size for TSR executables    */
#define   SQLPCAC   11002		/* CACHE size in Kbytes 	    */
#define   SQLPBRN   11003		/* brand of database		    */
#define   SQLPVER   1004		/* release version (ex. "4.0.J")    */
#define   SQLPPRF   1005		/* server profiling		    */
#define   SQLPPDB   11006		/* partitioned database 	    */
#define   SQLPGCM   1007		/* group commit count		    */
#define   SQLPGCD   1008		/* group commit delay ticks	    */

/*	Database specific parameters                                        */
#define   SQLPDBN   2001		/* database name		    */
#define   SQLPDDR   2002		/* database directory		    */
#define   SQLPLDR   2003		/* log directory		    */
#define   SQLPLFS   12004		/* log file size in Kbytes	    */
#define   SQLPCTI   12005		/* checkpoint time interval in mins */
#define   SQLPLBM   12006		/* log backup mode? (0 or 1)	    */
#define   SQLPPLF   12007		/* Pre-allocate log files? (0 or 1) */
#define   SQLPTSL   12008		/* transaction span limit	    */
#define   SQLPROT   12009		/* read-only transactions (0, 1, 2) */
#define   SQLPHFS   12010		/* history file size in Kbytes	    */
#define   SQLPREC   12011		/* recovery			    */
#define   SQLPEXE   2012		/* name of executable		    */
#define   SQLPNLB   12013		/* next log to backup		    */
#define   SQLPROD   12014		/* read-only database (0 or 1)	    */
#define   SQLPEXS   12015		/* database file extension size     */
#define   SQLPPAR   2016		/* partitioned database (0 or 1)    */
#define   SQLPNDB   2017		/* NEWDB			    */
#define   SQLPLGF   2018		/* log file offset		    */

/*	Cursor specific parameters                                          */
#define   SQLPISO   3001		/* isolation level (SQLILRR etc..)  */
#define   SQLPWTO   13002		/* lock wait timeout in seconds     */
#define   SQLPPCX   13003		/* preserve context (0 or 1)	    */
#define   SQLPFRS   13004		/* front end result sets	    */
#define   SQLPLDV   3005		/* load version (ex. "3.6.22")	    */
#define   SQLPAUT   13006		/* autocommit			    */
#define   SQLPRTO   13007		/* rollback trans on lock timeout   */
#define   SQLPSCR   13008		/* scroll mode (0 or 1) 	    */
#define   SQLPRES   13009		/* restriction mode (0 or 1)	    */
#define   SQLPFT    13010		/* fetch through		    */
#define   SQLPNPB   13011		/* no pre-build in RL mode	    */
#define   SQLPPWD   3012		/* current password		    */
#define   SQLPDB2   3013		/* DB2 compatibility mode	    */
#define   SQLPREF   3014		/* referential integrity checking   */
#define   SQLPBLK   3015		/* bulk-execute mode		    */
#define   SQLPOBL   3016		/* optimized bulk-execute mode	    */
#define   SQLPLFF   13017		/* LONG data allowed in FERS	    */
#define   SQLPDIS   13018		/* When to return Describe info     */
#define   SQLPCMP   13019		/* Compress messages sent to server */
#define   SQLPCHS   13020		/* chained cmd has SELECT (0 or 1)  */
#define   SQLPOPL   13021		/* optimizer level		    */
#define   SQLPRID   3022		/* ROWID			    */

/*	Static attributes                                                   */
#define   SQLPFAT   4000		/* first attribute		    */
#define   SQLPBRS   14001		/* back end result sets 	    */
#define   SQLPMUL   14002		/* multi-user			    */
#define   SQLPDMO   4003		/* demonstration version	    */
#define   SQLPLOC   14004		/* local version of database	    */
#define   SQLPLAT   4005		/* last attribute		    */

/*	Server specific parameters                                          */
#define   SQLPPLV   15001		/* print level			    */
#define   SQLPALG   5002		/* activity log 		    */
#define   SQLPTMS   15003		/* time stamp			    */

/*	SQL Server & Router/Gateway specific parameters                     */
#define   SQLPESTR  5101		/* get server error # and string    */
#define   SQLPMSTR  5102		/* get server msg# and string	    */
#define   SQLPMAPC  5103		/* MapGTICursors		    */
#define   SQLPUPRE  5104		/* get user prefix		    */
#define   SQLPORID  5105		/* Oracle RowID 		    */
#define   SQLPERRM  5106		/* error mapping		    */

/* end of SET and GET PARAMETER TYPES */




/* defines for isolation level string */
#define   SQLILRR   "RR"		/* Repeatable Read isolation	    */
#define   SQLILCS   "CS"		/* Cursor Stability isolation	    */
#define   SQLILRO   "RO"		/* Read-Only isolation		    */
#define   SQLILRL   "RL"		/* Release Locks isolation	    */




/* RESULT COMMAND TYPES */
#define   SQLTSEL   1			/* select			    */
#define   SQLTINS   2			/* insert			    */
#define   SQLTCTB   3			/* create table 		    */
#define   SQLTUPD   4			/* update			    */
#define   SQLTDEL   5			/* delete			    */
#define   SQLTCIN   6			/* create index 		    */
#define   SQLTDIN   7			/* drop index			    */
#define   SQLTDTB   8			/* drop table			    */
#define   SQLTCMT   9			/* commit			    */
#define   SQLTRBK   10			/* rollback			    */
#define   SQLTACO   11			/* add column			    */
#define   SQLTDCO   12			/* drop column			    */
#define   SQLTRTB   13			/* rename table 		    */
#define   SQLTRCO   14			/* rename column		    */
#define   SQLTMCO   15			/* modify column		    */
#define   SQLTGRP   16			/* grant privilege on table	    */
#define   SQLTGRD   17			/* grant dba			    */
#define   SQLTGRC   18			/* grant connect		    */
#define   SQLTGRR   19			/* grant resource		    */
#define   SQLTREP   20			/* revoke privilege on table	    */
#define   SQLTRED   21			/* revoke dba			    */
#define   SQLTREC   22			/* revoke connect		    */
#define   SQLTRER   23			/* revoke resource		    */
#define   SQLTCOM   24			/* comment on			    */
#define   SQLTWAI   25			/* wait 			    */
#define   SQLTPOS   26			/* post 			    */
#define   SQLTCSY   27			/* create synonym		    */
#define   SQLTDSY   28			/* drop synonym 		    */
#define   SQLTCVW   29			/* create view			    */
#define   SQLTDVW   30			/* drop view			    */
#define   SQLTRCT   31			/* row count			    */
#define   SQLTAPW   32			/* alter password		    */
#define   SQLTLAB   33			/* label on			    */
#define   SQLTCHN   34			/* chained command		    */
#define   SQLTRPT   35			/* repair table 		    */
#define   SQLTSVP   36			/* savepoint			    */
#define   SQLTRBS   37			/* rollback to savepoint	    */
#define   SQLTUDS   38			/* update statistics		    */
#define   SQLTCDB   39			/* check database		    */
#define   SQLTFRN   40			/* foreign DBMS commands	    */
#define   SQLTAPK   41			/* add primary key		    */
#define   SQLTAFK   42			/* add foreign key		    */
#define   SQLTDPK   43			/* drop primary key		    */
#define   SQLTDFK   44			/* drop foreign key		    */
/* SERVER COMMAND TYPES */
#define   SQLTCDA   45			/* create dbarea		    */
#define   SQLTADA   46			/* alter  dbarea		    */
#define   SQLTDDA   47			/* delete dbarea		    */
#define   SQLTCSG   48			/* create stogroup		    */
#define   SQLTASG   49			/* alter  stogroup		    */
#define   SQLTDSG   50			/* delete stogroup		    */
#define   SQLTCRD   51			/* create database		    */
#define   SQLTADB   52			/* alter  database		    */
#define   SQLTDDB   53			/* delete database		    */
#define   SQLTSDS   54			/* set default stogroup 	    */
#define   SQLTIND   55			/* install database		    */
#define   SQLTDED   56			/* de-install database		    */
/* END OF SERVER COMMAND TYPES */
#define   SQLTARU   57			/* add RI user error		    */
#define   SQLTDRU   58			/* drop RI user error		    */
#define   SQLTMRU   59			/* modify RI user error 	    */
#define   SQLTSCL   60			/* set client			    */




/* defines for database brands */

#define   SQLBSQB    1			/* SQLBASE			    */
#define   SQLBDB2    2			/* DB2				    */
#define   SQLBDBM    3			/* IBM OS/2 Database Manager	    */
#define   SQLBORA    4			/* Oracle			    */
#define   SQLBIGW    5			/* Informix			    */
#define   SQLBNTW    6			/* Netware SQL			    */
#define   SQLBAS4    7			/* IBM AS/400 SQL/400		    */
#define   SQLBSYB    8			/* Sybase SQL Server		    */
#define   SQLBDBC    9			/* Teradata DBC Machines	    */
#define   SQLBALB   10			/* HP Allbase			    */
#define   SQLBRDB   11			/* DEC's RDB			    */
#define   SQLBTDM   12			/* Tandem's Nonstop SQL 	    */
#define   SQLBSDS   13			/* IBM SQL/DS			    */
#define   SQLBSES   14			/* SNI SESAM			    */
#define   SQLBING   15			/* Ingres			    */
#define   SQLBSQL   16			/* SQL Access			    */
#define   SQLBDBA   17			/* DBase			    */
#define   SQLBDB4   18			/* SNI DDB4			    */
#define   SQLBFUJ   19			/* Fujitsu RDBII		    */
#define   SQLBSUP   20			/* Cincom SUPRA 		    */
#define   SQLB204   21			/* CCA Model 204		    */
#define   SQLBDAL   22			/* Apple DAL interface		    */
#define   SQLBSHR   23			/* Teradata ShareBase		    */
#define   SQLBAPP   99			/* SQLHost App Services 	    */



/* defines for ON, OFF, DEFAULT parameter values			    */

#define   SQLVOFF    0			/* parameter should be OFF	    */
#define   SQLVON     1			/* parameter should be ON	    */
#define   SQLVDFL    2			/* parameter should default	    */



/// by LMN   |-)
